@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2020 Kevin B. Hendricks Stratford, ON, Canada 
+**  Copyright (C) 2015-2021 Kevin B. Hendricks Stratford, ON, Canada 
 **  Copyright (C) 2012      John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012      Dave Heiland
 **
@@ -31,7 +31,7 @@
 #include <QDebug>
 
 #include "ResourceObjects/HTMLResource.h"
-#include "Misc/GumboInterface.h"
+#include "Parsers/GumboInterface.h"
 #include "BookManipulation/XhtmlDoc.h"
 #include "MiscEditors/IndexEditorModel.h"
 #include "BookManipulation/Index.h"
@@ -164,13 +164,13 @@ bool Index::CreateIndexEntry(const QString text, HTMLResource *html_resource, QS
             QString index_entry = entry->index_entry;
             if (index_entry.isEmpty()) {
                 // If no index text, use the pattern
-	        IndexEntries::instance()->AddOneEntry(index_pattern, html_resource->GetRelativePath(), index_id_value);
+                IndexEntries::instance()->AddOneEntry(index_pattern, html_resource->GetRelativePath(), index_id_value);
             } else if (entry->index_entry.endsWith("/")) {
                 // If index text is a category then append the pattern
-	        IndexEntries::instance()->AddOneEntry(index_entry + index_pattern, html_resource->GetRelativePath(), index_id_value);
+                IndexEntries::instance()->AddOneEntry(index_entry + index_pattern, html_resource->GetRelativePath(), index_id_value);
             } else {
                 // Use the given index text
-	        IndexEntries::instance()->AddOneEntry(index_entry, html_resource->GetRelativePath(), index_id_value);
+                IndexEntries::instance()->AddOneEntry(index_entry, html_resource->GetRelativePath(), index_id_value);
             }
         }
     }
