@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2021 Kevin B. Hendricks, Stratford, Ontario
+**  Copyright (C) 2015-2023 Kevin B. Hendricks, Stratford, Ontario
 **  Copyright (C) 2012      John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012-2013 Dave Heiland
 **
@@ -308,6 +308,11 @@ QString AllFilesWidget::GetType(Resource *resource)
             break;
         }
 
+        case Resource::PdfResourceType: {
+            type = tr("PDF");
+            break;
+        }
+
         case Resource::FontResourceType: {
             type = tr("Font");
             break;
