@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2021 Kevin B. Hendricks, Stratford, Ontario Canada
+**  Copyright (C) 2015-2022 Kevin B. Hendricks, Stratford, Ontario Canada
 **  Copyright (C) 2009-2011 Strahinja Markovic  <strahinja.markovic@gmail.com>
 **
 **  This file is part of Sigil.
@@ -23,11 +23,11 @@
 #include <memory>
 #include <functional>
 
-#include <QtCore/QtCore>
-#include <QtCore/QDir>
-#include <QtCore/QFileInfo>
-#include <QtCore/QFutureSynchronizer>
-#include <QtConcurrent/QtConcurrent>
+#include <QtCore>
+#include <QDir>
+#include <QFileInfo>
+#include <QFutureSynchronizer>
+#include <QtConcurrent>
 #include <QDebug>
 
 #include "BookManipulation/CleanSource.h"
@@ -36,6 +36,7 @@
 #include "BookManipulation/XhtmlDoc.h"
 #include "Importers/ImportHTML.h"
 #include "Parsers/GumboInterface.h"
+#include "Parsers/OPFParser.h" // for MetaEntry
 #include "Misc/HTMLEncodingResolver.h"
 #include "Misc/SettingsStore.h"
 #include "Misc/TempFolder.h"
@@ -253,15 +254,26 @@ QHash<QString, QString> ImportHTML::LoadFolderStructure(const QString &source)
     QStringList mediapaths = XhtmlDoc::GetPathsToMediaFiles(source);
     QStringList stylepaths = XhtmlDoc::GetPathsToStyleFiles(source);
     QFutureSynchronizer<QHash<QString, QString>> sync;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)    
     sync.addFuture(QtConcurrent::run(this, &ImportHTML::LoadMediaFiles,  mediapaths));
     sync.addFuture(QtConcurrent::run(this, &ImportHTML::LoadStyleFiles,  stylepaths));
+#else
+    sync.addFuture(QtConcurrent::run(&ImportHTML::LoadMediaFiles, this,  mediapaths));
+    sync.addFuture(QtConcurrent::run(&ImportHTML::LoadStyleFiles, this,  stylepaths));
+#endif
     sync.waitForFinished();
     QList<QFuture<QHash<QString, QString>>> futures = sync.futures();
     int num_futures = futures.count();
     QHash<QString, QString> updates;
 
     for (int i = 0; i < num_futures; ++i) {
+        
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         updates.unite(futures.at(i).result());
+#else
+        updates.insert(futures.at(i).result());
+#endif
+        
     }
 
     return updates;
