@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2019 Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2015-2021 Kevin B. Hendricks, Stratford Ontario Canada
 **  Copyright (C) 2009-2011 Strahinja Markovic  <strahinja.markovic@gmail.com>
 **
 **  This file is part of Sigil.
@@ -106,6 +106,8 @@ public:
      */
     QList <Resource *> AllCSSResources();
 
+    QList <Resource *> AllJSResources();
+
     void SelectResources(QList<Resource *> resources);
 
     void RemoveSelection(QList<Resource *> tab_resources);
@@ -181,6 +183,7 @@ public slots:
     void CopyCSS();
     void AddNewHTML();
     void AddNewCSS();
+    void AddNewJS();
     void AddNewSVG();
     CSSResource* CreateHTMLTOCCSSFile();
     CSSResource* CreateIndexCSSFile();
@@ -210,6 +213,8 @@ public slots:
      */
     void SelectMovedResource();
 
+    void FocusOnBookBrowser();
+
     void SaveAsUrl(const QUrl &url);
 
 signals:
@@ -257,6 +262,8 @@ signals:
 
     void LinkStylesheetsToResourcesRequest(QList<Resource *> resources);
 
+    void LinkJavascriptsToResourcesRequest(QList<Resource *> resources);
+
     void RemoveResourcesRequest();
 
     void OpenFileRequest(QString, int, int);
@@ -346,6 +353,8 @@ private slots:
 
     void LinkStylesheets();
 
+    void LinkJavascripts();
+
     /**
      * Clears obfuscation for the current resource.
      */
@@ -499,6 +508,7 @@ private:
     QAction *m_CopyCSS;
     QAction *m_AddNewHTML;
     QAction *m_AddNewCSS;
+    QAction *m_AddNewJS;
     QAction *m_AddNewSVG;
     QAction *m_AddExisting;
     QAction *m_Rename;
@@ -514,6 +524,7 @@ private:
     QAction *m_SortHTML;
     QAction *m_RenumberTOC;
     QAction *m_LinkStylesheets;
+    QAction *m_LinkJavascripts;
     QAction *m_AddSemantics;
     QAction *m_SaveAs;
     QAction *m_ValidateWithW3C;
