@@ -1,6 +1,6 @@
 /***************************************************************************
 **
-**  Copyright (C) 2015-2022 Kevin B. Hendricks, Stratford, Ontario, Canada
+**  Copyright (C) 2015-2023 Kevin B. Hendricks, Stratford, Ontario, Canada
 **  Copyright (C) 2011-2012 John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012      Dave Heiland
 **  Copyright (C) 2009-2011 Strahinja Markovic  <strahinja.markovic@gmail.com>
@@ -1730,6 +1730,8 @@ void FindReplace::LoadSearch(SearchEditorModel::searchEntry *search_entry)
 void FindReplace::SetStartingResource(bool update_position)
 {
     bool manual_restart = m_RestartPerformed;
+    Q_UNUSED(manual_restart);
+    
     m_RestartPerformed = false;
 
     if (isWhereCF() || m_LookWhereCurrentFile || IsMarkedText()) return;
@@ -1760,7 +1762,8 @@ void FindReplace::SetStartingResource(bool update_position)
     // new searches at the top (or bottom) of the current file if it is in the set.
     // Also, when the user hits Restart, the next search should start at the top (bottom)
     
-    if (m_IsSearchGroupRunning || manual_restart ) {
+    // if (m_IsSearchGroupRunning || manual_restart ) {
+    if (m_IsSearchGroupRunning) {
         if ( m_StartingResource == current_resource ) {
             int pos = 0;
             if (GetSearchDirection() == FindReplace::SearchDirection_Up) {
