@@ -26,7 +26,7 @@
 #ifndef FINDREPLACE_H
 #define FINDREPLACE_H
 
-#include <QtCore/QTimer>
+#include <QTimer>
 
 #include "ui_FindReplace.h"
 #include "BookManipulation/FolderKeeper.h"
@@ -35,6 +35,8 @@
 #include "MiscEditors/SearchEditorModel.h"
 #include "ViewEditors/Searchable.h"
 
+class QMenu;
+class QAction;
 class Resource;
 class MainWindow;
 
@@ -90,8 +92,13 @@ public:
     bool isWhereOPF() { return GetLookWhere() == LookWhere_OPFFile; };
     bool isWhereNCX() { return GetLookWhere() == LookWhere_NCXFile; };
     bool isWhereCF()  { return GetLookWhere() == LookWhere_CurrentFile; };
-
-
+    bool isSearchXML();
+    
+    QString GetSearchRegex();
+    QString GetReplace();
+    QList<Resource*> GetAllResourcesToSearch();
+    void EmitOpenFileRequest(const QString& bookpath, int line, int pos);
+                                                                        
 public slots:
     void close();
     void show();
@@ -105,12 +112,19 @@ public slots:
     void ReplaceAllSearch();
     void DoRestart();
 
+    // Shows a message in the main window.
+    void ShowMessage(const QString &message);
+    void clearMessage();
+
+    void DryRunComplete() { m_DryRunRunning = false; clearMessage(); };
+
     bool FindMisspelledWord();
 
     void SetRegexOptionDotAll(bool new_state);
     void SetRegexOptionMinimalMatch(bool new_state);
     void SetRegexOptionAutoTokenise(bool new_state);
     void SetOptionWrap(bool new_state);
+    void SetRegexOptionTextOnly(bool new_state);
 
     bool FindAnyText(QString text, bool escape = true);
     void FindAnyTextInTags(QString text);
@@ -121,12 +135,16 @@ public slots:
 
     void ValidateRegex();
 
+    void CountsReportCount(SearchEditorModel::searchEntry* entry, int& count);
+
 signals:
 
     void OpenSearchEditorRequest(SearchEditorModel::searchEntry *search_entry = NULL);
 
     void ShowMessageRequest(const QString &message);
 
+    void FROpenFileRequest(const QString &bookpath, int line, int offset);
+    
     /**
      * Emitted when we want to do some operations with the clipboard
      * to paste things, but restoring state afterwards so that the
@@ -140,9 +158,6 @@ protected:
 
 private slots:
 
-    // Shows a message in the main window.
-    void ShowMessage(const QString &message);
-
     bool IsMarkedText();
 
     void FindClicked();
@@ -176,6 +191,13 @@ private slots:
     bool DoReplaceNext();
     bool DoReplacePrevious();
 
+    // Does a Dry Run Find A// / Replace All  and shows results in table
+    void PerformDryRunReplace();
+
+    // Allows a user to choose which matches in Replace All should
+    // be applied
+    void ChooseReplacements();
+    
     // Replaces the user's search term with the user's
     // replacement text in the entire document. Shows a
     // dialog telling how many occurrences were replaced.
@@ -186,7 +208,6 @@ private slots:
     void ReplaceAllInFile();
     void CountInFile();
 
-    void clearMessage();
     void expireMessage();
 
     void SaveSearchAction();
@@ -195,7 +216,7 @@ private slots:
 
     void ClearHistory();
 
-    void AdvancedOptionsClicked();
+    // void AdvancedOptionsClicked();
 
 private:
 
@@ -205,7 +226,6 @@ private:
     void SetStartingResource(bool update_position = true);
 
     QString GetControls();
-    
     Searchable::Direction GetSearchableDirection();
     bool FindText(Searchable::Direction direction);
     bool ReplaceText(Searchable::Direction direction, bool replace_current = false);
@@ -222,7 +242,6 @@ private:
 
     // Constructs a searching regex from the selected
     // options and fields and then returns it.
-    QString GetSearchRegex();
     QString PrependRegexOptionToSearch(const QString &option, const QString &search);
 
     QList <Resource *> GetFilesToSearch(bool force_all = false);
@@ -295,7 +314,11 @@ private:
     // Writes all the stored dialog settings
     void WriteSettings();
 
-    void ShowHideAdvancedOptions();
+    // void ShowHideAdvancedOptions();
+
+    // Set all F&R buttons to text-only
+    // Default: icon-only
+    void SetFRButtonsTextOnly();
 
     void ExtendUI();
 
@@ -306,7 +329,7 @@ private:
     QString TokeniseForRegex(const QString &text, bool includeNumerics);
 
     void WriteSettingsVisible(bool visible);
-    void WriteSettingsAdvancedVisible(bool advanced);
+    // void WriteSettingsAdvancedVisible(bool advanced);
 
     /**
      * Connects all the required signals to their respective slots.
@@ -332,7 +355,7 @@ private:
     bool m_RegexOptionMinimalMatch;
     bool m_RegexOptionAutoTokenise;
     bool m_OptionWrap;
-
+    bool m_RegexOptionTextOnly;
     bool m_SpellCheck;
 
     bool m_LookWhereCurrentFile;
@@ -352,6 +375,15 @@ private:
     bool m_RestartPerformed;
 
     bool m_SearchRunning;
+
+    bool m_DryRunRunning;
+
+    bool m_ShiftUsed;
+
+    QAction* m_DotAllCheckAction;
+    QAction* m_MinimalMatchCheckAction;
+    QAction* m_AutoTokeniseCheckAction;
+    QMenu*   m_menu;
 };
 
 
