@@ -1,9 +1,9 @@
 /************************************************************************
 **
-**  Copyright (C) 2019 Kevin B. Hendricks, Stratford, Ontario Canada
-**  Copyright (C) 2012 John Schember <john@nachtimwald.com>
-**  Copyright (C) 2012 Grant Drake
-**  Copyright (C) 2012 Dave Heiland
+**  Copyright (C) 2019-2020 Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2012      John Schember <john@nachtimwald.com>
+**  Copyright (C) 2012      Grant Drake
+**  Copyright (C) 2012      Dave Heiland
 **
 **  This file is part of Sigil.
 **
@@ -28,6 +28,10 @@
 
 #include <QEvent>
 #include <QtWidgets/QApplication>
+#include <QString>
+#include <QHash>
+
+class QStyle;
 
 class MainApplication : public QApplication
 {
@@ -36,13 +40,28 @@ class MainApplication : public QApplication
 public:
     MainApplication(int &argc, char **argv);
 
+    bool isDarkMode() { return m_isDark; }
+    void fixMacDarkModePalette(QPalette &pal);
+
+    void saveInPreviewCache(const QString &key, const QString& xhtml);
+    QString loadFromPreviewCache(const QString &key);
+    
 signals:
     void applicationActivated();
     void applicationDeactivated();
+    void applicationPaletteChanged();
+
+public slots:
+    void EmitPaletteChanged();
 
 protected:
     bool event(QEvent *pEvent);
 
+private:
+    QStyle * m_Style;
+    bool m_isDark;
+    QHash<QString, QString> m_PreviewCache;
+    // QStringList m_CacheKeys;
 };
 
 #endif // MAINAPPLICATION_H
