@@ -1,7 +1,7 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2022  Kevin B. Hendricks, Stratford Ontario Canada
-**  Copyright (C) 2019-2022  Doug Massay
+**  Copyright (C) 2015-2023  Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2019-2023  Doug Massay
 **  Copyright (C) 2012       Dave Heiland, John Schember
 **
 **  This file is part of Sigil.
@@ -44,6 +44,7 @@
 #include "Misc/SleepFunctions.h"
 #include "Misc/SettingsStore.h"
 #include "Misc/Utility.h"
+#include "Misc/webviewprinter.h"
 #include "ViewEditors/ViewPreview.h"
 #include "ViewEditors/Overlay.h"
 #include "sigil_constants.h"
@@ -78,7 +79,9 @@ PreviewWindow::PreviewWindow(QWidget *parent)
     m_titleText(QString()),
     m_updatingPage(false),
     m_usingMathML(false),
-    m_cycleCSSLevel(0)
+    m_cycleCSSLevel(0),
+    m_skipPrintPreview(false),
+    m_WebViewPrinter(new WebViewPrinter(this))
 {
     m_progress->reset();
     m_progress->setMinimum(0);
@@ -226,7 +229,7 @@ void PreviewWindow::SetupView()
     // QWebEngineView events are routed to their parent
     m_Preview->installEventFilter(this);
 
-#if !defined(Q_OS_WIN32) && !defined(Q_OS_MAC)
+#if 1 //!defined(Q_OS_WIN32) && !defined(Q_OS_MAC)
     // this may be needed by all platforms in the future
     QWidget * fp = m_Preview->focusProxy();
     if (fp) fp->installEventFilter(this);
@@ -254,6 +257,13 @@ void PreviewWindow::SetupView()
     m_cycleCSSAction = new QAction(QIcon(":/main/cycle-css.svg"),"", this);
     m_cycleCSSAction ->setEnabled(false);
     m_cycleCSSAction->setToolTip(tr("Cycle Custom CSS Files"));
+
+    QIcon pricon;
+    pricon.addFile(":/main/document-print.svg", QSize(), QIcon::Normal);
+    pricon.addFile(":/main/busy-working.svg", QSize(), QIcon::Disabled);
+    m_webviewPrint = new QAction(pricon, "", this);
+    m_webviewPrint ->setEnabled(true);
+    m_webviewPrint->setToolTip(tr("Print Preview View"));
     
     QToolBar * tb = new QToolBar();
     tb->addAction(m_inspectAction);
@@ -261,6 +271,7 @@ void PreviewWindow::SetupView()
     tb->addAction(m_copyAction);
     tb->addAction(m_reloadAction);
     tb->addAction(m_cycleCSSAction);
+    tb->addAction(m_webviewPrint);
     tb->addWidget(m_progress);
 
     m_buttons->addWidget(tb);
@@ -275,6 +286,17 @@ void PreviewWindow::SetupView()
 }
 
 
+void PreviewWindow::PrintStarted()
+{
+    m_webviewPrint ->setEnabled(false);
+}
+
+void PreviewWindow::PrintEnded()
+{
+    m_webviewPrint ->setEnabled(true);
+}
+
+
 void PreviewWindow::CycleCustomCSS()
 {
     if (m_usercssurls.isEmpty()) return;
@@ -289,7 +311,6 @@ void PreviewWindow::CycleCustomCSS()
 // you must delay before trying to update Preview to a specific location
 bool PreviewWindow::UpdatePage(QString filename_url, QString text, QList<ElementIndex> location)
 {
-
     DBG qDebug() << "Entered PV UpdatePage with filename: " << filename_url;
 
     if (!m_Preview->isVisible()) {
@@ -352,6 +373,9 @@ bool PreviewWindow::UpdatePage(QString filename_url, QString text, QList<Element
         }
     }
 
+
+#if QT_VERSION <= QT_VERSION_CHECK(5, 12, 5)
+    // This workaround to a QtWebEngine bug is no longer needed after Qt 5.12.5
     if (fixup_fullscreen_svg_images(text)) {
         QRegularExpression svg_height("<\\s*svg\\s[^>]*height\\s*=\\s*[\"'](100%)[\"'][^>]*>",
                                      QRegularExpression::CaseInsensitiveOption |
@@ -375,7 +399,8 @@ bool PreviewWindow::UpdatePage(QString filename_url, QString text, QList<Element
             text = text.replace(bp, n, "100vw"); 
         }
     }
-
+#endif
+    
     m_Filepath = filename_url;
     m_Preview->CustomSetDocument(filename_url, text);
 
@@ -385,6 +410,9 @@ bool PreviewWindow::UpdatePage(QString filename_url, QString text, QList<Element
 
 void PreviewWindow::UpdatePageDone()
 {
+    // ignore spurious page DocumentLoaded signals from ViewPreview
+    if (!m_updatingPage) return;
+
     if (!m_Preview->WasLoadOkay()) qDebug() << "PV loadFinished with okay set to false!";
  
     DBG qDebug() << "PreviewWindow UpdatePage load is Finished";
@@ -616,6 +644,28 @@ void PreviewWindow::InspectPreviewPage()
     m_Inspector->close();
 }
 
+
+void PreviewWindow::PrintRendered()
+{
+#if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
+    // Refresh skipflags from Prefs
+    SettingsStore settings;
+    m_skipPrintPreview = settings.skipPrintPreview();
+    m_WebViewPrinter->setContent(m_Filepath, m_Preview->GetHTML(), m_skipPrintPreview);
+#else
+    QMessageBox msgbox;
+    QString text = tr("Feature not available before Qt5.12.x");
+    msgbox.setWindowFlags(Qt::Window | Qt::WindowStaysOnTopHint);
+    msgbox.setModal(true);
+    msgbox.setWindowTitle("Sigil");
+    msgbox.setText("<h3>" + text + "</h3><br/>");
+    msgbox.setIcon(QMessageBox::Icon::Warning);
+    msgbox.setStandardButtons(QMessageBox::Close);
+    msgbox.exec();
+#endif
+
+}
+
 void PreviewWindow::SelectAllPreview()
 {
     m_Preview->triggerPageAction(QWebEnginePage::SelectAll);
@@ -660,12 +710,15 @@ void PreviewWindow::ConnectSignalsToSlots()
     connect(m_Preview,   SIGNAL(LinkClicked(const QUrl &)), this, SLOT(LinkClicked(const QUrl &)));
     connect(m_Preview,   SIGNAL(DocumentLoaded()),          this, SLOT(UpdatePageDone()));
     connect(m_Preview,   SIGNAL(ViewProgress(int)),         this, SLOT(setProgress(int)));
-    connect(m_inspectAction, SIGNAL(triggered()),           this, SLOT(InspectPreviewPage()));
-    connect(m_selectAction,  SIGNAL(triggered()),           this, SLOT(SelectAllPreview()));
-    connect(m_copyAction,    SIGNAL(triggered()),           this, SLOT(CopyPreview()));
-    connect(m_reloadAction,  SIGNAL(triggered()),           this, SLOT(ReloadPreview()));
-    connect(m_cycleCSSAction, SIGNAL(triggered()),          this, SLOT(CycleCustomCSS())); 
-    connect(m_Inspector,     SIGNAL(finished(int)),         this, SLOT(InspectorClosed(int)));
+    connect(m_inspectAction,  SIGNAL(triggered()),          this, SLOT(InspectPreviewPage()));
+    connect(m_selectAction,   SIGNAL(triggered()),          this, SLOT(SelectAllPreview()));
+    connect(m_copyAction,     SIGNAL(triggered()),          this, SLOT(CopyPreview()));
+    connect(m_reloadAction,   SIGNAL(triggered()),          this, SLOT(ReloadPreview()));
+    connect(m_cycleCSSAction, SIGNAL(triggered()),          this, SLOT(CycleCustomCSS()));
+    connect(m_webviewPrint,   SIGNAL(triggered()),          this, SLOT(PrintRendered()));
+    connect(m_WebViewPrinter, SIGNAL(printStarted()),       this, SLOT(PrintStarted()));
+    connect(m_WebViewPrinter, SIGNAL(printEnded()),         this, SLOT(PrintEnded()));
+    connect(m_Inspector,      SIGNAL(finished(int)),        this, SLOT(InspectorClosed(int)));
     connect(this,     SIGNAL(topLevelChanged(bool)),        this, SLOT(previewFloated(bool)));
 }
 
