@@ -107,7 +107,7 @@ int SearchOperations::CountInHTMLFile(const QString &search_regex,
     // any text resource can come from an internal cache that can go away
     const QString text = html_resource->GetText();
     if (check_spelling) {
-        return HTMLSpellCheck::CountMisspelledWords(text, 0, text.count(), search_regex);
+        return HTMLSpellCheck::CountMisspelledWords(text, 0, text.length(), search_regex);
     } else {
         return PCRECache::instance()->getObject(search_regex)->getEveryMatchInfo(text).count();
     }
@@ -205,7 +205,7 @@ std::tuple<QString, int> SearchOperations::PerformHTMLSpellCheckReplace(const QS
     int count = 0;
     int offset = 0;
     SPCRE *spcre = PCRECache::instance()->getObject(search_regex);
-    QList<HTMLSpellCheck::MisspelledWord> check_spelling = HTMLSpellCheck::GetMisspelledWords(text, 0, text.count(), search_regex);
+    QList<HTMLSpellCheck::MisspelledWord> check_spelling = HTMLSpellCheck::GetMisspelledWords(text, 0, text.length(), search_regex);
     foreach(HTMLSpellCheck::MisspelledWord misspelled_word, check_spelling) {
         SPCRE::MatchInfo match_info = spcre->getFirstMatchInfo(misspelled_word.text);
 
