@@ -1,7 +1,7 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2022 Kevin B. Hendricks, Stratford Ontario Canada
-**  Copyright (C) 2016-2020 Doug Massay
+**  Copyright (C) 2015-2023 Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2016-2023 Doug Massay
 **  Copyright (C) 2009-2011 Strahinja Markovic  <strahinja.markovic@gmail.com>
 **
 **  This file is part of Sigil.
@@ -68,7 +68,7 @@
 #include "Misc/SleepFunctions.h"
 #include "MainUI/MainApplication.h"
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
     #define QT_ENUM_SKIPEMPTYPARTS Qt::SkipEmptyParts
     #define QT_ENUM_KEEPEMPTYPARTS Qt::KeepEmptyParts
 #else
@@ -79,7 +79,7 @@
 static const QString URL_SAFE = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789_.-/~";
 
 static const QString DARK_STYLE =
-    "<style>:root { background-color: %1; color: %2; } ::-webkit-scrollbar { display: none; }</style>"
+    "<style id=\"Sigil_Injected\">:root { background-color: %1; color: %2; } ::-webkit-scrollbar { display: none; }</style>"
     "<link rel=\"stylesheet\" type=\"text/css\" href=\"%3\" />";
 
 #ifndef MAX_PATH
@@ -495,7 +495,10 @@ QString Utility::GetTemporaryFileNameWithExtension(const QString &extension)
     SettingsStore ss;
     QString temp_path = ss.tempFolderHome();
     if (temp_path == "<SIGIL_DEFAULT_TEMP_HOME>") {
-        temp_path = QDir::tempPath();
+        temp_path = DefinePrefsDir() + "/workspace";
+    }
+    if (!QDir(temp_path).exists()) {
+        temp_path = DefinePrefsDir() + "/workspace";
     }
     return temp_path +  "/sigil_" + Utility::CreateUUID() + extension;
 }
@@ -1037,7 +1040,7 @@ QStringList Utility::ZipInspect(const QString &zippath)
 QString Utility::longestCommonPath(const QStringList& filepaths, const QString& sep)
 {
     if (filepaths.isEmpty()) return QString();
-    if (filepaths.length() == 1) return QFileInfo(filepaths.at(0)).absolutePath() + sep;
+    if (filepaths.length() == 1) return QFileInfo(filepaths.at(0)).filePath() + sep;
     QStringList fpaths(filepaths);
     fpaths.sort();
     const QStringList segs1 = fpaths.first().split(sep);
