@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2022 Kevin B. Hendricks  Stratford, ON Canada
+**  Copyright (C) 2015-2023 Kevin B. Hendricks  Stratford, ON Canada
 **  Copyright (C) 2013      John Schember <john@nachtimwald.com>
 **  Copyright (C) 2009-2011 Strahinja Markovic  <strahinja.markovic@gmail.com>
 **
@@ -49,7 +49,7 @@
 #include "sigil_constants.h"
 #include "sigil_exception.h"
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
     #define QT_ENUM_SKIPEMPTYPARTS Qt::SkipEmptyParts
     #define QT_ENUM_KEEPEMPTYPARTS Qt::KeepEmptyParts
 #else
@@ -531,7 +531,7 @@ void OPFResource::AutoFixWellFormedErrors()
             }
         }
         std::sort(txts.begin(), txts.end(), Utility::sort_string_pairs_by_first);
-        for (int j=0; j < txts.size(); j++) {
+        for (unsigned int j=0; j < txts.size(); j++) {
             QString idref = txts.at(j).second;
             SpineEntry sp;
             sp.m_idref = idref;
