@@ -6,10 +6,14 @@ __all__ = [
     'LXMLTreeBuilder',
     ]
 
+try:
+    from collections.abc import Callable # Python 3.6
+except ImportError as e:
+    from collections import Callable
+
 from io import BytesIO
 from io import StringIO
 
-import collections
 from lxml import etree
 from sigil_bs4.element import (
     Comment,
@@ -64,16 +68,16 @@ class LXMLTreeBuilderForXML(TreeBuilder):
         if self._default_parser is not None:
             return self._default_parser
         return etree.XMLParser(
-            target=self, strip_cdata=False, recover=True, encoding=encoding, resolve_entities=False)
+            target=self, strip_cdata=False, recover=True, encoding=encoding, resolve_entities=True)
 
     def parser_for(self, encoding):
         # Use the default parser.
         parser = self.default_parser(encoding)
 
-        if isinstance(parser, collections.Callable):
+        if isinstance(parser, Callable):
             # Instantiate the parser with default arguments
             if self.is_xml:
-                parser = parser(target=self, strip_cdata=False, encoding=encoding, resolve_entities=False)
+                parser = parser(target=self, strip_cdata=False, encoding=encoding, resolve_entities=True)
             else:
                 parser = parser(target=self, strip_cdata=False, encoding=encoding)
         return parser
