@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2016-2020 Kevin B. Hendricks, Stratford, Ontario Canada
+**  Copyright (C) 2016-2021 Kevin B. Hendricks, Stratford, Ontario Canada
 **  Copyright (C) 2009-2011 Strahinja Markovic  <strahinja.markovic@gmail.com>
 **
 **  This file is part of Sigil.
@@ -23,7 +23,7 @@
 #include <memory>
 #include <functional>
 
-#include "Misc/EmbeddedPython.h"
+#include "EmbedPython/EmbeddedPython.h"
 #include <QtCore/QtCore>
 #include <QtCore/QString>
 #include <QtCore/QHash>
@@ -31,7 +31,7 @@
 #include <QDebug>
 
 #include "Misc/Utility.h"
-#include "Misc/GumboInterface.h"
+#include "Parsers/GumboInterface.h"
 #include "BookManipulation/CleanSource.h"
 #include "ResourceObjects/HTMLResource.h"
 #include "ResourceObjects/NCXResource.h"
@@ -57,14 +57,20 @@ void AnchorUpdates::UpdateExternalAnchors(const QList<HTMLResource *> &html_reso
 }
 
 
-// used to update after merge of html_resources into new_file
-void AnchorUpdates::UpdateAllAnchors(const QList<HTMLResource *> &html_resources, const QStringList &originating_bookpaths, HTMLResource *sink_res)
+// used for merge to fix all anchors outside the merge to point to the sink
+void AnchorUpdates::UpdateAllAnchors(const QList<HTMLResource *> &html_resources,
+                                     const QStringList &originating_bookpaths,
+                                     HTMLResource *sink_res,
+                                     const QHash<QString,QString> &section_id_map)
 {
     QList<HTMLResource *> new_files;
     new_files.append(sink_res);
-    const QHash<QString, QString> &ID_locations = GetIDLocations(new_files);
     QString sink_bookpath = sink_res->GetRelativePath();
-    QtConcurrent::blockingMap(html_resources, std::bind(UpdateAllAnchorsInOneFile, std::placeholders::_1, originating_bookpaths, ID_locations, sink_bookpath));
+    QtConcurrent::blockingMap(html_resources, std::bind(UpdateAllAnchorsInOneFile, 
+                                                        std::placeholders::_1,
+                                                        originating_bookpaths,
+                                                        sink_bookpath,
+                                                        section_id_map));
 }
 
 
@@ -123,40 +129,40 @@ void AnchorUpdates::UpdateAnchorsInOneFile(HTMLResource *html_resource,
             QString href = QString::fromUtf8(attr->value);
             if (href.indexOf(':') == -1) {
                 std::pair<QString, QString> parts = Utility::parseRelativeHREF(href);
-		// if fragment exists
+                 // if fragment exists
                 if (!parts.second.isEmpty()) {
                     QString base_href = parts.first;
                     QString fragment_id = parts.second;
                     if (fragment_id.startsWith("#")) fragment_id = fragment_id.mid(1, -1);
                     QString dest_bookpath = Utility::buildBookPath(base_href, Utility::startingDir(resource_bookpath));
-		    QString file_id = ID_locations.value(fragment_id);
+                    QString file_id = ID_locations.value(fragment_id);
 
                     DBG qDebug() << "base_href" << base_href;
-		    DBG qDebug() << "destination bookpath" << dest_bookpath;
-		    DBG qDebug() << "fragment_id" << fragment_id;
-		    DBG qDebug() << "file_id" << file_id;
-		    DBG qDebug() << "resource_bookpath" << resource_bookpath;
+                    DBG qDebug() << "destination bookpath" << dest_bookpath;
+                    DBG qDebug() << "fragment_id" << fragment_id;
+                    DBG qDebug() << "file_id" << file_id;
+                    DBG qDebug() << "resource_bookpath" << resource_bookpath;
 
-		    // Duplicates of this id may exist in other xhtml files in the epub
-		    // not involved in the split, so only set the target file_id if the
-		    // original dest_bookpath is one that was impacted by split
-		    if (!base_href.isEmpty() && !bookpaths_impacted.contains(dest_bookpath)) {
-		        file_id = "";
+                    // Duplicates of this id may exist in other xhtml files in the epub
+                    // not involved in the split, so only set the target file_id if the
+                    // original dest_bookpath is one that was impacted by split
+                    if (!base_href.isEmpty() && !bookpaths_impacted.contains(dest_bookpath)) {
+                        file_id = "";
                         DBG qDebug() << "Not in bookpaths_impacted!" << dest_bookpath; 
-		    }
-		    
+                    }
+            
                     // If the ID is in a different file, update the link
                     if (file_id != resource_bookpath && !file_id.isEmpty()) {
                         QString attpath = Utility::buildRelativePath(resource_bookpath, file_id);
-		        QString attribute_value = Utility::buildRelativeHREF(attpath, "#" + fragment_id);
+                        QString attribute_value = Utility::buildRelativeHREF(attpath, "#" + fragment_id);
                         gumbo_attribute_set_value(attr, attribute_value.toUtf8().constData());
                         is_changed = true;
                     } else if ((file_id == resource_bookpath) && !base_href.isEmpty()) {
-		        // this is a local internal link that needs to be fixed
+                        // this is a local internal link that needs to be fixed
                         QString attribute_value = QString("#").append(fragment_id);
                         gumbo_attribute_set_value(attr, attribute_value.toUtf8().constData());
                         is_changed = true;
-		    }
+                    }
                 }
             }
         }
@@ -204,7 +210,7 @@ void AnchorUpdates::UpdateExternalAnchorsInOneFile(HTMLResource *html_resource,
                     DBG qDebug() << "....... fragment_id" << fragment_id;
                    
                     if (fragment_id.startsWith('#')) fragment_id = fragment_id.mid(1, -1);
-		    target_bookpath = ID_locations.value(fragment_id);
+                    target_bookpath = ID_locations.value(fragment_id);
                     DBG qDebug() << "....... NEW target_bookpath" << target_bookpath;
 
                     QString attpath = Utility::buildRelativePath(html_resource->GetRelativePath(), target_bookpath);
@@ -224,13 +230,14 @@ void AnchorUpdates::UpdateExternalAnchorsInOneFile(HTMLResource *html_resource,
 }
 
 
+// Used for merge not splits
 // walk all links in html_resource and look for any that end with a bookpath in
 // originating_bookpaths and change it to be in the sink resource which is a 
 // product of the merge
 void AnchorUpdates::UpdateAllAnchorsInOneFile(HTMLResource *html_resource,
-        const QList<QString> &originating_bookpaths,
-        const QHash<QString, QString> ID_locations,
-	const QString & sink_bookpath)
+                                              const QList<QString> &originating_bookpaths,
+                                              const QString &sink_bookpath,
+                                              const QHash<QString, QString> &section_id_map)
 {
     Q_ASSERT(html_resource);
     QWriteLocker locker(&html_resource->GetLock());
@@ -252,8 +259,15 @@ void AnchorUpdates::UpdateAllAnchorsInOneFile(HTMLResource *html_resource,
                 std::pair<QString, QString> parts = Utility::parseRelativeHREF(href);
                 DBG qDebug() << "In UpdateAllAnchorsInOneFile doing merge: " << parts.first << parts.second;
                 // Does this href point to a bookpath in the originating_bookpaths
-	        QString target_bookpath = Utility::buildBookPath(parts.first, startdir);
-	        if (originating_bookpaths.contains(target_bookpath)) {
+                QString target_bookpath = Utility::buildBookPath(parts.first, startdir);
+                if (originating_bookpaths.contains(target_bookpath)) {
+                    if (parts.second.isEmpty()) {
+                        // this href went to the top of a merged file, so use the injected section links
+                        // to update it
+                        if (section_id_map.contains(target_bookpath)) {
+                            parts.second = "#" + section_id_map[target_bookpath];
+                        }
+                    }
                     QString attpath = Utility::buildRelativePath(html_resource->GetRelativePath(), sink_bookpath);
                     QString attribute_value = Utility::buildRelativeHREF(attpath, parts.second);
                     gumbo_attribute_set_value(attr, attribute_value.toUtf8().constData());
@@ -304,10 +318,10 @@ void AnchorUpdates::UpdateTOCEntries(NCXResource *ncx_resource, const QString &o
                                          &rv,
                                          error_traceback);    
     if (rv != 0) {
-      Utility::DisplayStdWarningDialog(QString("error in xmlprocessor anchorNCXUpdates: ") + QString::number(rv), 
+        Utility::DisplayStdWarningDialog(QString("error in xmlprocessor anchorNCXUpdates: ") + QString::number(rv), 
                                        error_traceback);
-      // an error happened - make no changes
-      return;
+        // an error happened - make no changes
+        return;
     }
     ncx_resource->SetText(res.toString());
 }
@@ -340,11 +354,10 @@ void AnchorUpdates::UpdateTOCEntriesAfterMerge(NCXResource *ncx_resource, const
                                          &rv,
                                          error_traceback);    
     if (rv != 0) {
-      Utility::DisplayStdWarningDialog(QString("error in xmlprocessor anchorNCXUpdatesAfterMerge: ") + QString::number(rv), 
+        Utility::DisplayStdWarningDialog(QString("error in xmlprocessor anchorNCXUpdatesAfterMerge: ") + QString::number(rv), 
                                        error_traceback);
-      // an error happened - make no changes
-      return;
+        // an error happened - make no changes
+        return;
     }
     ncx_resource->SetText(res.toString());
 }
-
