@@ -1,6 +1,7 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2020 Kevin B. Hendricks, Stratford, Ontario, Canada
+**  Copyright (C) 2015-2021 Kevin B. Hendricks, Stratford, Ontario, Canada
+**  Copyright (C) 2021 Doug Massay
 **  Copyright (C) 2009-2011 Strahinja Markovic  <strahinja.markovic@gmail.com>
 **
 **  This file is part of Sigil.
@@ -26,10 +27,16 @@
 #include <QString>
 #include <QRegularExpression>
 #include <QRegularExpressionMatch>
+#include <QDebug>
 
 #include "Misc/Utility.h"
 #include "SourceUpdates/PerformCSSUpdates.h"
 
+// Expression debugging
+#define DBG if(0)
+// Start index/increment debugging
+#define DBG2 if(0)
+
 static const QChar FORWARD_SLASH = QChar::fromLatin1('/');
 
 PerformCSSUpdates::PerformCSSUpdates(const QString &source, 
@@ -56,13 +63,20 @@ QString PerformCSSUpdates::operator()()
 
     // Now parse the text once looking for keys and replacing them where needed
     QRegularExpression reference(
-        "(?:(?:src|background|background-image|list-style|list-style-image|border-image|border-image-source|content|(?:-webkit-)?shape-outside)\\s*:|@import)\\s*"
+        "(?:(?:src|background|background-image|block|border|border-image|border-image-source|"
+        "content|cursor|list-style|list-style-image|mask|mask-image|(?:-webkit-)?shape-outside)\\s*:|"
+        "@import)\\s*"
         "("
         "[^;\\}]*"
         ")"
         "(?:;|\\})");
 
     QRegularExpression urls(
+        "(?:"
+        "url\\([\"']?([^\\(\\)\"']*)[\"']?\\)"
+        ")");
+
+    QRegularExpression importurls(
         "(?:"
         "url\\([\"']?([^\\(\\)\"']*)[\"']?\\)"
         "|"
@@ -70,6 +84,7 @@ QString PerformCSSUpdates::operator()()
         ")");
 
     int start_index = 0;
+    int start_index_correction = 0;
     QRegularExpressionMatch mo = reference.match(result, start_index);
     // handle case if no initial match at all
     if (!mo.hasMatch()) return result;
@@ -79,14 +94,26 @@ QString PerformCSSUpdates::operator()()
             if (mo.captured(i).trimmed().isEmpty()) {
                 continue;
             }
+            DBG2 qDebug() << "start index is: " << QString::number(start_index);
+            DBG2 qDebug() << "i is: " << QString::number(i);
+            DBG2 qDebug() << mo.captured(i) << " start: " << mo.capturedStart(i) << " len: " << mo.capturedLength(i);
             // Check the captured property attribute string fragment for multiple urls
             int frag_start_index = 0;
+            int frag_index_correction = 0;
             QString fragment = mo.captured(i);
+            if(mo.captured().startsWith("@import", Qt::CaseInsensitive)) {
+                DBG qDebug() << "Using alternate expression for @import urls";
+                DBG qDebug() << mo.captured();
+                urls.swap(importurls);
+            }
             QRegularExpressionMatch frag_mo = urls.match(fragment, frag_start_index);
             // only loop if at least one match was found
             if (frag_mo.hasMatch()) {
+                DBG2 qDebug() << "urls.matches found " << QString::number(urls.captureCount());
                 do {
                     for (int j = 1; j <= urls.captureCount(); ++j) {
+                        DBG2 qDebug() << "processing url match number: " << QString::number(j);
+                        DBG2 qDebug() << "frag_mo is: " << frag_mo.captured(j);
                         if (frag_mo.captured(j).trimmed().isEmpty()) {
                             continue;
                         }
@@ -104,21 +131,25 @@ QString PerformCSSUpdates::operator()()
                             if (new_href != frag_mo.captured(j)) {
                                 new_href = Utility::URLEncodePath(new_href);
                                 fragment.replace(frag_mo.capturedStart(j), frag_mo.capturedLength(j), new_href);
+                                frag_index_correction += new_href.length() - frag_mo.capturedLength(j);
                                 changes_made = true;
                             }
                         }
                     }
-                    frag_start_index += frag_mo.capturedLength();
+                    frag_start_index = frag_mo.capturedEnd() + frag_index_correction;
+                    frag_index_correction = 0;
                     frag_mo = urls.match(fragment, frag_start_index);
                 } while (frag_mo.hasMatch());
             }
             // Replace the original attribute string fragment with the new one
             if (changes_made) {
                 result.replace(mo.capturedStart(i), mo.capturedLength(i), fragment);
+                start_index_correction += fragment.length() - mo.capturedLength(i);
             }
 
         }
-        start_index = mo.capturedEnd();
+        start_index = mo.capturedEnd() + start_index_correction;
+        start_index_correction = 0;
         mo = reference.match(result, start_index);
     } while (mo.hasMatch());
 
