@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2016-2021  Kevin B Hendricks, Stratford, Ontario, Canada
+**  Copyright (C) 2016-2023  Kevin B Hendricks, Stratford, Ontario, Canada
 **  Copyright (C) 2012       John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012       Dave Heiland
 **  Copyright (C) 2012       Grant Drake
@@ -129,7 +129,6 @@ void FlowTab::CreateCodeViewIfRequired(bool is_delayed_load)
     QApplication::setOverrideCursor(Qt::WaitCursor);
     m_wCodeView = new CodeViewEditor(CodeViewEditor::Highlight_XHTML, true, this);
     m_wCodeView->SetReformatHTMLEnabled(true);
-    // m_views->addWidget(m_wCodeView);
 
     if (is_delayed_load) {
         ConnectCodeViewSignalsToSlots();
@@ -1029,7 +1028,7 @@ void FlowTab::ChangeCasing(const Utility::Casing casing)
 void FlowTab::HeadingStyle(const QString &heading_type, bool preserve_attributes)
 {
     if (m_wCodeView) {
-        QChar last_char = heading_type[ heading_type.count() - 1 ];
+        QChar last_char = heading_type[ heading_type.length() - 1 ];
 
         // For heading_type == "Heading #"
         if (last_char.isDigit()) {
