@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2019-2020 Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2019-2023 Kevin B. Hendricks, Stratford Ontario Canada
 **
 **  This file is part of Sigil.
 **
@@ -19,16 +19,17 @@
 **
 *************************************************************************/
 #include <QUrl>
+#include <QWebEngineProfile>
 #include <QDebug>
 #include "Misc/Utility.h"
 #include "ViewEditors/SimplePage.h"
 
  
-SimplePage::SimplePage(QObject *parent)
-    : QWebEnginePage(parent)
+SimplePage::SimplePage(QWebEngineProfile* profile, QObject *parent)
+    : QWebEnginePage(profile, parent)
 {
     setBackgroundColor(Utility::WebViewBackgroundColor(true));
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0) || QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
     setUrl(QUrl("about:blank"));
 #endif
 }
