@@ -1,7 +1,7 @@
 /************************************************************************
 **
-**  Copyright (C) 2019-2021 Kevin B. Hendricks, Stratford Ontario Canada
-**  Copyright (C) 2019-2021 Doug Massay
+**  Copyright (C) 2019-2023 Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2019-2023 Doug Massay
 **
 **  This file is part of Sigil.
 **
@@ -39,6 +39,7 @@
 #include <QDebug>
 
 #include "MainUI/MainApplication.h"
+#include "Misc/WebProfileMgr.h"
 #include "Misc/SettingsStore.h"
 #include "Misc/Utility.h"
 #include "sigil_constants.h"
@@ -48,7 +49,7 @@
 
 #define DBG if(0)
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
     #define QT_ENUM_SKIPEMPTYPARTS Qt::SkipEmptyParts
     #define QT_ENUM_KEEPEMPTYPARTS Qt::KeepEmptyParts
 #else
@@ -88,11 +89,27 @@ struct SetJavascriptResultFunctor {
     }
 };
 
-ViewPreview::ViewPreview(QWidget *parent)
+struct HTMLResult {
+   QString res;
+   bool finished;
+   HTMLResult() : res(QString("")), finished(false) {}
+   HTMLResult(HTMLResult * pRes) : res(pRes->res),  finished(pRes->finished) {}
+   bool isFinished() { return finished; }
+ };
+
+ struct SetToHTMLResultFunctor {
+     HTMLResult * pres;
+     SetToHTMLResultFunctor(HTMLResult * pres) : pres(pres) {}
+     void operator()(const QString &result) {
+         pres->res = result;
+         pres->finished = true;
+     }
+ };
+
+ViewPreview::ViewPreview(QWidget *parent, bool setbackground)
     : QWebEngineView(parent),
       m_isLoadFinished(false),
-      m_ViewWebPage(new WebEngPage(this)),
-      c_jQuery(Utility::ReadUnicodeTextFile(":/javascript/jquery-2.2.4.min.js")),
+      c_jQuery(Utility::ReadUnicodeTextFile(":/javascript/jquery-3.6.4.min.js")),
       c_jQueryScrollTo(Utility::ReadUnicodeTextFile(":/javascript/jquery.scrollTo-2.1.2-min.js")),
       c_GetCaretLocation(Utility::ReadUnicodeTextFile(":/javascript/book_view_current_location.js")),
       m_CaretLocationUpdate(QString()),
@@ -101,30 +118,22 @@ ViewPreview::ViewPreview(QWidget *parent)
       m_LoadOkay(false),
       m_overlay(new LoadingOverlay(this))
 {
+    QWebEngineProfile* profile = WebProfileMgr::instance()->GetPreviewProfile();
+    m_ViewWebPage = new WebEngPage(profile, this, setbackground);
     setPage(m_ViewWebPage);
-    // Now handled in the WebEngPage constructor to be faster
-    // page()->setBackgroundColor(Utility::WebViewBackgroundColor(true));
     setContextMenuPolicy(Qt::CustomContextMenu);
     // Set the Zoom factor but be sure no signals are set because of this.
-    SettingsStore settings;
-    SetCurrentZoomFactor(settings.zoomPreview());
-    page()->settings()->setAttribute(QWebEngineSettings::ErrorPageEnabled, false);
-    page()->settings()->setAttribute(QWebEngineSettings::PluginsEnabled, false);
-    page()->settings()->setDefaultTextEncoding("UTF-8");
-    // Javascript is allowed 
-    page()->settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, (settings.javascriptOn() == 1));
-    page()->settings()->setAttribute(QWebEngineSettings::JavascriptCanOpenWindows, (settings.javascriptOn() == 1));
-    // Allow epubs to access remote resources via the net
-    page()->settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, (settings.remoteOn() == 1));
-    page()->settings()->setAttribute(QWebEngineSettings::FocusOnNavigationEnabled, false);
-    // Enable local-storage for epub3
-    page()->settings()->setAttribute(QWebEngineSettings::LocalStorageEnabled, true);
-    QString localStorePath = Utility::DefinePrefsDir() + "/local-storage";
-    QDir storageDir(localStorePath);
-    if (!storageDir.exists()) {
-        storageDir.mkpath(localStorePath);
-    }
-    page()->profile()->setPersistentStoragePath(localStorePath);
+    SettingsStore ss;
+    SetCurrentZoomFactor(ss.zoomPreview());
+    
+    // Update the Preview's Profile Settings with User's Preferences
+    m_ViewWebPage->profile()->settings()->setAttribute(QWebEngineSettings::JavascriptEnabled,
+                                                       (ss.javascriptOn() == 1));
+    m_ViewWebPage->profile()->settings()->setAttribute(QWebEngineSettings::JavascriptCanOpenWindows,
+                                                       (ss.javascriptOn() == 1));
+    m_ViewWebPage->profile()->settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls,
+                                                       (ss.remoteOn() == 1));
+
     ConnectSignalsToSlots();
 }
 
@@ -330,6 +339,19 @@ void ViewPreview::ShowOverlay()
     m_overlay->show();
 }
 
+QString ViewPreview::GetHTML() const 
+ {
+     HTMLResult * pres = new HTMLResult();
+     page()->toHtml(SetToHTMLResultFunctor(pres));
+     while(!pres->isFinished()) {
+         qApp->processEvents(QEventLoop::ExcludeUserInputEvents | QEventLoop::ExcludeSocketNotifiers, 100);
+     }
+     QString res = pres->res;
+     delete pres;
+     return res;
+ }
+
+
 QVariant ViewPreview::EvaluateJavascript(const QString &javascript)
 {
     DBG qDebug() << "EvaluateJavascript: " << m_isLoadFinished;
