@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2019-2021 Kevin B. Hendricks
+**  Copyright (C) 2019-2023 Kevin B. Hendricks
 **  Copyright (C) 2013      Dave Heiland
 **
 **  This file is part of Sigil.
@@ -36,6 +36,7 @@
 
 #include "ViewEditors/SimplePage.h"
 #include "Misc/Utility.h"
+#include "Misc/WebProfileMgr.h"
 #include "Widgets/ImageView.h"
 
 static const QString IMAGE_HTML_BASE =
@@ -62,11 +63,12 @@ ImageView::ImageView(QWidget *parent)
     m_WebView(new QWebEngineView(this)),
     m_layout(new QVBoxLayout(this))
 {
-    m_WebView->setPage(new SimplePage(m_WebView));
+    QWebEngineProfile* profile = WebProfileMgr::instance()->GetOneTimeProfile();
+    m_WebView->setPage(new SimplePage(profile, m_WebView));
     m_WebView->setContextMenuPolicy(Qt::NoContextMenu);
     m_WebView->setFocusPolicy(Qt::NoFocus);
     m_WebView->setAcceptDrops(false);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)  || QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
     m_WebView->setUrl(QUrl("about:blank"));
 #endif
     m_layout->addWidget(m_WebView);
